jaraco.functools
================

.. image:: https://img.shields.io/pypi/v/jaraco.functools.svg
   :target: https://pypi.org/project/jaraco.functools

.. image:: https://img.shields.io/pypi/pyversions/jaraco.functools.svg

.. image:: https://img.shields.io/pypi/dm/jaraco.functools.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.functools/master.svg
   :target: http://travis-ci.org/jaraco/jaraco.functools

Additional functools in the spirit of stdlib's functools.
